@@ -56,7 +56,7 @@ sub call_app {
     }
 
     # Actually, we can not trust PATH_INFO from mod_perl because mod_perl squeezes multiple slashes into one slash.
-    my $uri = URI->new($r->unparsed_uri);
+    my $uri = URI->new("http://".$r->hostname.$r->unparsed_uri);
 
     $env->{PATH_INFO} = uri_unescape($uri->path);
 
